DimePayWebView class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- DimePayWebView
Constructors
-
DimePayWebView({Key? key, required int total, required String currency, required String orderId, required String clientId, required String data, DimePayMethods? payment_methods = const DimePayMethods(apple_pay: true, google_pay: true, samsung_pay: true), bool test = false, bool fakeWebView = false, List<
String> ? fakeMessages, DimePayStyles? styles, dynamic onReady(dynamic)?, dynamic onSuccess(dynamic)?, dynamic onFailed(dynamic)?, dynamic onError(dynamic)?, dynamic onCancel()?, dynamic onLoading()?, bool? is_subscription = false}) -
const
Properties
- clientId → String
-
final
- currency → String
-
final
- data → String
-
final
-
fakeMessages
→ List<
String> ? -
final
- fakeWebView → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- is_subscription → bool?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onCancel → dynamic Function()?
-
final
- onError → dynamic Function(dynamic)?
-
final
- onFailed → dynamic Function(dynamic)?
-
final
- onLoading → dynamic Function()?
-
final
- onReady → dynamic Function(dynamic)?
-
final
- onSuccess → dynamic Function(dynamic)?
-
final
- orderId → String
-
final
- payment_methods → DimePayMethods?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- styles → DimePayStyles?
-
final
- test → bool
-
final
- total → int
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< DimePayWebView> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited